@@ -29,6 +29,6 @@ def push_url(project, user):
 def push_json(url, data, session_id):
     headers = {'Content-Type': 'application/json',
                'Session-ID': session_id}
-    response = requests.post(url, json.dumps(data), headers=headers)
+    response = requests.post(url, json.dumps(data), headers=headers, verify=False)
     response.raise_for_status()
     return response
