@@ -15,14 +15,14 @@ from sbdk import VERSION
 
 DEFAULT_CONFIG = {
     'version': VERSION,
-    'default_base_image': 'sevenbridges/sdkbase:beta',
+    'default_base_image': 'sevenbridges/sdkbase',
     'logging_config': 'logging.json',
 
     'shell_type': 'bash',
     'pip_options': '-q --download-cache /sb/pip_cache',
     'sdk_runner_command': ['/usr/bin/python', '-m', 'sbgsdk.cli'],
-    'schema_server_url': 'https://sdk-alpha.sbgenomics.com:1180',
-    'file_server_url': 'sdk-alpha.sbgenomics.com',
+    'schema_server_url': 'https://beta2-48.sbgenomics.com:1180',
+    'file_server_url': 'beta2-48.sbgenomics.com',
     'vs_client_path': '/opt/vsclient/bin/vsclient.sh',
 
     'docker_registry_name': 'docker.sbgenomics.com:8888',
@@ -32,7 +32,7 @@ DEFAULT_CONFIG = {
     'docker_protocol_version': '1.8',
     'docker_user': 'sbg',
     'docker_dns': None,
-    'docker_entrypoint': None
+    'docker_entrypoint': ['/sbin/my_init', '--quiet', '--']
 }
 
 
